==> ultraman-bocp-metadata-client-0.1.5-sources.jar: com/xforceplus/ultraman/bocp/metadata/controller/AppDeployLogFeignApi.java <==
package com.xforceplus.ultraman.bocp.metadata.controller;


/**
 * 应用环境表feign客户端
 *
 * @author wangzheng
 * @date 2020-09-23
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.bocp.metadata.entity.AppDeployLog;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "ultraman-bocp-metadata")
public interface AppDeployLogFeignApi {

  /**
   * 通过id查询应用环境表
   * @param  id
   * @return R
   */
  @GetMapping("/appDeployLog/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增应用环境表
   * @param appDeployLog 应用环境表
   * @return R
   */
  @PostMapping("/appDeployLog/add")
  public R save(@RequestBody AppDeployLog appDeployLog);

  /**
   * 修改应用环境表
   * @param appDeployLog 应用环境表
   * @return R
   */
  @PostMapping("/appDeployLog/update")
  public R updateById(@RequestBody AppDeployLog appDeployLog);

  /**
   * 通过id删除应用环境表
   * @param  id
   * @return R
   */
  @DeleteMapping("/appDeployLog/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> ultraman-bocp-metadata-client-0.4.0-sources.jar: com/xforceplus/ultraman/bocp/metadata/controller/AppDeployLogFeignApi.java <==
package com.xforceplus.ultraman.bocp.metadata.controller;


/**
 * feign客户端
 *
 * @author wangzheng
 * @date 2021-11-17
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.bocp.metadata.entity.AppDeployLog;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "ultraman-bocp-metadata")
public interface AppDeployLogFeignApi {

  /**
   * 通过id查询
   * @param  id
   * @return R
   */
  @GetMapping("/appDeployLog/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增
   * @param appDeployLog 
   * @return R
   */
  @PostMapping("/appDeployLog/add")
  public R save(@RequestBody AppDeployLog appDeployLog);

  /**
   * 修改
   * @param appDeployLog 
   * @return R
   */
  @PostMapping("/appDeployLog/update")
  public R updateById(@RequestBody AppDeployLog appDeployLog);

  /**
   * 通过id删除
   * @param  id
   * @return R
   */
  @DeleteMapping("/appDeployLog/del/{id}" )
  public R removeById(@PathVariable Long id);

}
